@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Ohm;
-$Bot::Cobalt::Plugin::Ohm::VERSION = '0.001002';
+$Bot::Cobalt::Plugin::Ohm::VERSION = '1.001001';
 # A simple Ohm's law calculator borrowed from SYMKAT:
 # https://gist.github.com/symkat/da287f0993e708b53701
 
@@ -8,6 +8,8 @@ use strictures 2;
 use Bot::Cobalt;
 use Bot::Cobalt::Common;
 
+use Regexp::Common 'number';
+
 sub new { bless [], shift }
 
 sub Cobalt_register {
@@ -45,22 +47,9 @@ sub Bot_public_cmd_ohm {
   my $str = join '', @{ $msg->message_array };
   my %parsed = $self->_parse_values($str);
 
-  my $resp;
-  RESP: {
-    unless (keys %parsed) {
-      $resp = "Parser failure, try input in the form of: <I>a <P>w <R>o <E>v";
-      last RESP
-    }
-
-    $resp = 
-      try { $self->_calc(%parsed) }
-        catch { "Calc failure; $_" };
-
-    unless (length $resp) {
-      $resp = "Calc failure; malformed input from parser";
-      last RESP
-    }
-  } # RESP
+  my $resp = keys %parsed ?
+      try { $self->_calc(%parsed) } catch { "Calc failure; $_" }
+    : "Parser failure; try input in the form of: <I>a <P>w <R>o <E>v";
 
   broadcast message => $context, $msg->channel, "${src_nick}: $resp";
   
@@ -71,20 +60,13 @@ sub Bot_public_cmd_ohm {
 
 sub _parse_values {
   my ($self, $message) = @_;
-  my %values = ();
+  my %values;
 
-  if ( $message =~ /(\d+(?:\.\d+)?)o/i ) {
-    $values{o} = $1;
-  } 
-  if ( $message =~ /(\d+(?:\.\d+)?)w/i ) {
-    $values{w} = $1;
-  } 
-  if ( $message =~ /(\d+(?:\.\d+)?)a/i ) {
-    $values{a} = $1;
-  } 
-  if ( $message =~ /(\d+(?:\.\d+)?)v/i ) {
-    $values{v} = $1;
-  } 
+  for my $unit (qw/o w a v/) {
+    if ($message =~ m/($RE{num}{real})$unit/i) {
+      $values{$unit} = $1
+    }
+  }
 
   %values
 }
@@ -99,10 +81,8 @@ sub _calc {
         $values{v} && $values{o} ? $values{v} / $values{o}
       : $values{w} && $values{v} ? $values{w} / $values{v}
       : $values{w} && $values{o} ? sqrt( $values{w} / $values{o} )
-      : undef
+      : die "Not enough information to calculate amperage\n"
     ;
-    die "Not enough information to calculate amperage\n"
-      unless defined $values{a}
   }
   # W = ( V * V ) / O
   # W = ( A * A ) * O
@@ -112,10 +92,8 @@ sub _calc {
         $values{v} && $values{o} ? ($values{v} ** 2) / $values{o}
       : $values{a} && $values{o} ? ($values{a} ** 2) * $values{o}
       : $values{v} && $values{a} ? $values{v} * $values{a}
-      : undef
+      : die "Not enough information to calculate wattage\n"
     ;
-    die "Not enough information to calculate wattage\n"
-      unless defined $values{w}
   }
   # O = V / A
   # O = ( V * V ) * W
@@ -125,10 +103,8 @@ sub _calc {
         $values{v} && $values{a} ? $values{v} / $values{a}
       : $values{v} && $values{w} ? ($values{v} ** 2) * $values{w}
       : $values{w} && $values{a} ? $values{w} / ($values{a} ** 2)
-      : undef
+      : die "Not enough information to calculate ohms\n"
     ;
-    die "Not enough information to calculate ohms\n"
-      unless defined $values{o}
   }
   # V = sqrt( W * O )
   # V = W / A
@@ -138,10 +114,7 @@ sub _calc {
         $values{w} && $values{o} ? sqrt( $values{w} * $values{o} )
       : $values{w} && $values{a} ? $values{w} / $values{a}
       : $values{a} && $values{o} ? $values{a} * $values{o}
-      : undef
-    ;
-    die "Not enough information to calculate voltage\n"
-      unless defined $values{v}
+      : die "Not enough information to calculate voltage\n"
   }
 
   sprintf 
